# Duplocloud Py Client  

A package to spawn service clients for working with Duplocloud. 

## Installation  

From PyPi:
```
pip install duplocloud-client
```

From source:
```
pip install .
```

## Build  

Build the package
```
python -m build
```

## Commands  

Get the current version
```
python -m setuptools_scm
```